.. ORCID Hub documentation master file, created by
   sphinx-quickstart on Tue Nov 28 17:15:32 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ORCID Hub's documentation!
=====================================
|Build Status|\ |Coverage Status|

The home of development for the New Zealand ORCID Hub.

Because New Zealand ORCID Hub is fun to use.

Table of Contents
^^^^^^^^^^^^^^^^^
.. toctree::
   :maxdepth: 2
   :name: masterdoc

   installation
   writing_funding_items
   customising_email_messages
   ORCID API Specification <orcid_api_spec>

   development_env
   docker
   sendmail
   troubleshooting
   db_recovery
   pg_upgrade


Indices and tables
^^^^^^^^^^^^^^^^^^

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
